<?php
/**
* @file
* Hooks provided by this module.
*/

/**
* @addtogroup hooks
* @{
*/

/**
* Acts on Packages being loaded from the database.
*
* This hook is invoked during Package loading, which is handled by
* entity_load(), via the EntityCRUDController.
*
* @param array $packages
*   An array of Package entities being loaded, keyed by id.
*
* @see hook_entity_load()
*/
function hook_hosting_package_load(array $packages) {
  $result = db_query('SELECT pid, foo FROM {mytable} WHERE pid IN(:ids)', array(':ids' => array_keys($entities)));
  foreach ($result as $record) {
    $entities[$record->pid]->foo = $record->foo;
  }
}

/**
* Responds when a Package is inserted.
*
* This hook is invoked after the Package is inserted into the database.
*
* @param HostingPackage $package
*   The Package that is being inserted.
*
* @see hook_entity_insert()
*/
function hook_hosting_package_insert(HostingPackage $package) {
  db_insert('mytable')
    ->fields(array(
      'id' => entity_id('hosting_package', $package),
      'extra' => print_r($package, TRUE),
    ))
    ->execute();
}

/**
* Acts on a Package being inserted or updated.
*
* This hook is invoked before the Package is saved to the database.
*
* @param HostingPackage $package
*   The Package that is being inserted or updated.
*
* @see hook_entity_presave()
*/
function hook_hosting_package_presave(HostingPackage $package) {
  $package->name = 'foo';
}

/**
* Responds to a Package being updated.
*
* This hook is invoked after the Package has been updated in the database.
*
* @param HostingPackage $package
*   The Package that is being updated.
*
* @see hook_entity_update()
*/
function hook_hosting_package_update(HostingPackage $package) {
  db_update('mytable')
    ->fields(array('extra' => print_r($package, TRUE)))
    ->condition('id', entity_id('hosting_package', $package))
    ->execute();
}

/**
* Responds to Package deletion.
*
* This hook is invoked after the Package has been removed from the database.
*
* @param HostingPackage $package
*   The Package that is being deleted.
*
* @see hook_entity_delete()
*/
function hook_hosting_package_delete(HostingPackage $package) {
  db_delete('mytable')
    ->condition('pid', entity_id('hosting_package', $package))
    ->execute();
}

/**
* @}
*/
