<?php
/**
* @file
* Hooks provided by this module.
*/

/**
* @addtogroup hooks
* @{
*/

/**
* Acts on Servers being loaded from the database.
*
* This hook is invoked during Server loading, which is handled by
* entity_load(), via the EntityCRUDController.
*
* @param array $servers
*   An array of Server entities being loaded, keyed by id.
*
* @see hook_entity_load()
*/
function hook_hosting_server_load(array $servers) {
  $result = db_query('SELECT pid, foo FROM {mytable} WHERE pid IN(:ids)', array(':ids' => array_keys($entities)));
  foreach ($result as $record) {
    $entities[$record->pid]->foo = $record->foo;
  }
}

/**
* Responds when a Server is inserted.
*
* This hook is invoked after the Server is inserted into the database.
*
* @param HostingServer $server
*   The Server that is being inserted.
*
* @see hook_entity_insert()
*/
function hook_hosting_server_insert(HostingServer $server) {
  db_insert('mytable')
    ->fields(array(
      'id' => entity_id('hosting_server', $server),
      'extra' => print_r($server, TRUE),
    ))
    ->execute();
}

/**
* Acts on a Server being inserted or updated.
*
* This hook is invoked before the Server is saved to the database.
*
* @param HostingServer $server
*   The Server that is being inserted or updated.
*
* @see hook_entity_presave()
*/
function hook_hosting_server_presave(HostingServer $server) {
  $server->name = 'foo';
}

/**
* Responds to a Server being updated.
*
* This hook is invoked after the Server has been updated in the database.
*
* @param HostingServer $server
*   The Server that is being updated.
*
* @see hook_entity_update()
*/
function hook_hosting_server_update(HostingServer $server) {
  db_update('mytable')
    ->fields(array('extra' => print_r($server, TRUE)))
    ->condition('id', entity_id('hosting_server', $server))
    ->execute();
}

/**
* Responds to Server deletion.
*
* This hook is invoked after the Server has been removed from the database.
*
* @param HostingServer $server
*   The Server that is being deleted.
*
* @see hook_entity_delete()
*/
function hook_hosting_server_delete(HostingServer $server) {
  db_delete('mytable')
    ->condition('pid', entity_id('hosting_server', $server))
    ->execute();
}

/**
* @}
*/
